# Other 

## Sponsorship

Please consider sponsoring this project through [Github Sponsorship](https://github.com/sponsors/euvl) :pray:

## Development

```bash
# Clone repo
git clone https://github.com/euvl/vue-js-modal.git

# Run unit tests
npm run unit

# Run linter
npm run lint

# Build main library for client & SSR
cd vue-js-modal
npm install
npm run build

# Build and run demo
cd demo
npm install
npm run dev
```

## Check out

Check out my other projects:

* https://github.com/euvl/vue-notification
* https://github.com/euvl/vue-js-toggle-button
* https://github.com/euvl/vue-js-popover
* https://github.com/euvl/v-clipboard

## IE support

This plugin uses arrow functions, resize observer and other modern features.

To be able to use this plugin in IE you need to make sure you transpile the code properly. Please read this [stackoverflow](https://stackoverflow.com/questions/56446904/transpiling-es6-for-ie11-with-babel).
